==> tekton-model-triggers-5.10.1-sources.jar: io/fabric8/tekton/triggers/v1alpha1/WebhookInterceptorFluentImpl.java <==
package io.fabric8.tekton.triggers.v1alpha1;

import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import io.fabric8.kubernetes.api.model.ObjectReferenceFluentImpl;
import java.lang.String;
import java.util.function.Predicate;
import java.lang.Integer;
import io.fabric8.kubernetes.api.model.ObjectReference;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.model.ObjectReferenceBuilder;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import io.fabric8.tekton.pipeline.v1beta1.Param;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;

 /**
  * Generated
  */
public class WebhookInterceptorFluentImpl<A extends io.fabric8.tekton.triggers.v1alpha1.WebhookInterceptorFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.tekton.triggers.v1alpha1.WebhookInterceptorFluent<A>{
  public WebhookInterceptorFluentImpl() {
  }
  public WebhookInterceptorFluentImpl(io.fabric8.tekton.triggers.v1alpha1.WebhookInterceptor instance) {
    this.withHeader(instance.getHeader()); 
    this.withObjectRef(instance.getObjectRef()); 
    this.withUrl(instance.getUrl()); 
  }
  private java.util.List<io.fabric8.tekton.pipeline.v1beta1.Param> header;
  private io.fabric8.kubernetes.api.model.ObjectReferenceBuilder objectRef;
  private java.lang.String url;
  public A addToHeader(java.lang.Integer index,io.fabric8.tekton.pipeline.v1beta1.Param item) {
    if (this.header == null) {this.header = new java.util.ArrayList<io.fabric8.tekton.pipeline.v1beta1.Param>();}
    this.header.add(index, item);
    return (A)this;
  }
  public A setToHeader(java.lang.Integer index,io.fabric8.tekton.pipeline.v1beta1.Param item) {
    if (this.header == null) {this.header = new java.util.ArrayList<io.fabric8.tekton.pipeline.v1beta1.Param>();}
    this.header.set(index, item); return (A)this;
  }
  public A addToHeader(io.fabric8.tekton.pipeline.v1beta1.Param... items) {
    if (this.header == null) {this.header = new java.util.ArrayList<io.fabric8.tekton.pipeline.v1beta1.Param>();}
    for (io.fabric8.tekton.pipeline.v1beta1.Param item : items) {this.header.add(item);} return (A)this;
  }
  public A addAllToHeader(java.util.Collection<io.fabric8.tekton.pipeline.v1beta1.Param> items) {
    if (this.header == null) {this.header = new java.util.ArrayList<io.fabric8.tekton.pipeline.v1beta1.Param>();}
    for (io.fabric8.tekton.pipeline.v1beta1.Param item : items) {this.header.add(item);} return (A)this;
  }
  public A removeFromHeader(io.fabric8.tekton.pipeline.v1beta1.Param... items) {
    for (io.fabric8.tekton.pipeline.v1beta1.Param item : items) {if (this.header!= null){ this.header.remove(item);}} return (A)this;
  }
  public A removeAllFromHeader(java.util.Collection<io.fabric8.tekton.pipeline.v1beta1.Param> items) {
    for (io.fabric8.tekton.pipeline.v1beta1.Param item : items) {if (this.header!= null){ this.header.remove(item);}} return (A)this;
  }
  public java.util.List<io.fabric8.tekton.pipeline.v1beta1.Param> getHeader() {
    return this.header;
  }
  public io.fabric8.tekton.pipeline.v1beta1.Param getHeader(java.lang.Integer index) {
    return this.header.get(index);
  }
  public io.fabric8.tekton.pipeline.v1beta1.Param getFirstHeader() {
    return this.header.get(0);
  }
  public io.fabric8.tekton.pipeline.v1beta1.Param getLastHeader() {
    return this.header.get(header.size() - 1);
  }
  public io.fabric8.tekton.pipeline.v1beta1.Param getMatchingHeader(java.util.function.Predicate<io.fabric8.tekton.pipeline.v1beta1.Param> predicate) {
    for (io.fabric8.tekton.pipeline.v1beta1.Param item: header) { if(predicate.test(item)){ return item;} } return null;
  }
  public java.lang.Boolean hasMatchingHeader(java.util.function.Predicate<io.fabric8.tekton.pipeline.v1beta1.Param> predicate) {
    for (io.fabric8.tekton.pipeline.v1beta1.Param item: header) { if(predicate.test(item)){ return true;} } return false;
  }
  public A withHeader(java.util.List<io.fabric8.tekton.pipeline.v1beta1.Param> header) {
    if (header != null) {this.header = new java.util.ArrayList<io.fabric8.tekton.pipeline.v1beta1.Param>(); for (io.fabric8.tekton.pipeline.v1beta1.Param item : header){this.addToHeader(item);}} else { this.header = null;} return (A) this;
  }
  public A withHeader(io.fabric8.tekton.pipeline.v1beta1.Param... header) {
    if (this.header != null) {this.header.clear();}
    if (header != null) {for (io.fabric8.tekton.pipeline.v1beta1.Param item :header){ this.addToHeader(item);}} return (A) this;
  }
  public java.lang.Boolean hasHeader() {
    return header != null && !header.isEmpty();
  }
  
  /**
   * This method has been deprecated, please use method buildObjectRef instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.kubernetes.api.model.ObjectReference getObjectRef() {
    return this.objectRef!=null?this.objectRef.build():null;
  }
  public io.fabric8.kubernetes.api.model.ObjectReference buildObjectRef() {
    return this.objectRef!=null?this.objectRef.build():null;
  }
  public A withObjectRef(io.fabric8.kubernetes.api.model.ObjectReference objectRef) {
    _visitables.get("objectRef").remove(this.objectRef);
    if (objectRef!=null){ this.objectRef= new io.fabric8.kubernetes.api.model.ObjectReferenceBuilder(objectRef); _visitables.get("objectRef").add(this.objectRef);} return (A) this;
  }
  public java.lang.Boolean hasObjectRef() {
    return this.objectRef != null;
  }
  public io.fabric8.tekton.triggers.v1alpha1.WebhookInterceptorFluent.ObjectRefNested<A> withNewObjectRef() {
    return new io.fabric8.tekton.triggers.v1alpha1.WebhookInterceptorFluentImpl.ObjectRefNestedImpl();
  }
  public io.fabric8.tekton.triggers.v1alpha1.WebhookInterceptorFluent.ObjectRefNested<A> withNewObjectRefLike(io.fabric8.kubernetes.api.model.ObjectReference item) {
    return new io.fabric8.tekton.triggers.v1alpha1.WebhookInterceptorFluentImpl.ObjectRefNestedImpl(item);
  }
  public io.fabric8.tekton.triggers.v1alpha1.WebhookInterceptorFluent.ObjectRefNested<A> editObjectRef() {
    return withNewObjectRefLike(getObjectRef());
  }
  public io.fabric8.tekton.triggers.v1alpha1.WebhookInterceptorFluent.ObjectRefNested<A> editOrNewObjectRef() {
    return withNewObjectRefLike(getObjectRef() != null ? getObjectRef(): new io.fabric8.kubernetes.api.model.ObjectReferenceBuilder().build());
  }
  public io.fabric8.tekton.triggers.v1alpha1.WebhookInterceptorFluent.ObjectRefNested<A> editOrNewObjectRefLike(io.fabric8.kubernetes.api.model.ObjectReference item) {
    return withNewObjectRefLike(getObjectRef() != null ? getObjectRef(): item);
  }
  public java.lang.String getUrl() {
    return this.url;
  }
  public A withUrl(java.lang.String url) {
    this.url=url; return (A) this;
  }
  public java.lang.Boolean hasUrl() {
    return this.url != null;
  }
  
  /**
   * Method is deprecated. use withUrl instead.
   */
  @java.lang.Deprecated
  public A withNewUrl(java.lang.String arg0) {
    return (A)withUrl(new String(arg0));
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    WebhookInterceptorFluentImpl that = (WebhookInterceptorFluentImpl) o;
    if (header != null ? !header.equals(that.header) :that.header != null) return false;
    if (objectRef != null ? !objectRef.equals(that.objectRef) :that.objectRef != null) return false;
    if (url != null ? !url.equals(that.url) :that.url != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(header,  objectRef,  url,  super.hashCode());
  }
  public class ObjectRefNestedImpl<N> extends io.fabric8.kubernetes.api.model.ObjectReferenceFluentImpl<io.fabric8.tekton.triggers.v1alpha1.WebhookInterceptorFluent.ObjectRefNested<N>> implements io.fabric8.tekton.triggers.v1alpha1.WebhookInterceptorFluent.ObjectRefNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{
    ObjectRefNestedImpl(io.fabric8.kubernetes.api.model.ObjectReference item) {
      this.builder = new io.fabric8.kubernetes.api.model.ObjectReferenceBuilder(this, item);
    }
    ObjectRefNestedImpl() {
      this.builder = new io.fabric8.kubernetes.api.model.ObjectReferenceBuilder(this);
    }
    io.fabric8.kubernetes.api.model.ObjectReferenceBuilder builder;
    public N and() {
      return (N) WebhookInterceptorFluentImpl.this.withObjectRef(builder.build());
    }
    public N endObjectRef() {
      return and();
    }
    
  }
  
}

==> tekton-model-triggers-5.12.2-sources.jar: io/fabric8/tekton/triggers/v1alpha1/WebhookInterceptorFluentImpl.java <==
package io.fabric8.tekton.triggers.v1alpha1;

import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import io.fabric8.kubernetes.api.model.ObjectReferenceFluentImpl;
import java.lang.String;
import java.util.function.Predicate;
import java.lang.Integer;
import io.fabric8.kubernetes.api.model.ObjectReference;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.model.ObjectReferenceBuilder;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import io.fabric8.tekton.pipeline.v1beta1.Param;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;

 /**
  * Generated
  */
public class WebhookInterceptorFluentImpl<A extends io.fabric8.tekton.triggers.v1alpha1.WebhookInterceptorFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.tekton.triggers.v1alpha1.WebhookInterceptorFluent<A>{
  public WebhookInterceptorFluentImpl() {
  }
  public WebhookInterceptorFluentImpl(io.fabric8.tekton.triggers.v1alpha1.WebhookInterceptor instance) {
    this.withHeader(instance.getHeader()); 
    this.withObjectRef(instance.getObjectRef()); 
    this.withUrl(instance.getUrl()); 
  }
  private java.util.List<io.fabric8.tekton.pipeline.v1beta1.Param> header;
  private io.fabric8.kubernetes.api.model.ObjectReferenceBuilder objectRef;
  private java.lang.String url;
  public A addToHeader(java.lang.Integer index,io.fabric8.tekton.pipeline.v1beta1.Param item) {
    if (this.header == null) {this.header = new java.util.ArrayList<io.fabric8.tekton.pipeline.v1beta1.Param>();}
    this.header.add(index, item);
    return (A)this;
  }
  public A setToHeader(java.lang.Integer index,io.fabric8.tekton.pipeline.v1beta1.Param item) {
    if (this.header == null) {this.header = new java.util.ArrayList<io.fabric8.tekton.pipeline.v1beta1.Param>();}
    this.header.set(index, item); return (A)this;
  }
  public A addToHeader(io.fabric8.tekton.pipeline.v1beta1.Param... items) {
    if (this.header == null) {this.header = new java.util.ArrayList<io.fabric8.tekton.pipeline.v1beta1.Param>();}
    for (io.fabric8.tekton.pipeline.v1beta1.Param item : items) {this.header.add(item);} return (A)this;
  }
  public A addAllToHeader(java.util.Collection<io.fabric8.tekton.pipeline.v1beta1.Param> items) {
    if (this.header == null) {this.header = new java.util.ArrayList<io.fabric8.tekton.pipeline.v1beta1.Param>();}
    for (io.fabric8.tekton.pipeline.v1beta1.Param item : items) {this.header.add(item);} return (A)this;
  }
  public A removeFromHeader(io.fabric8.tekton.pipeline.v1beta1.Param... items) {
    for (io.fabric8.tekton.pipeline.v1beta1.Param item : items) {if (this.header!= null){ this.header.remove(item);}} return (A)this;
  }
  public A removeAllFromHeader(java.util.Collection<io.fabric8.tekton.pipeline.v1beta1.Param> items) {
    for (io.fabric8.tekton.pipeline.v1beta1.Param item : items) {if (this.header!= null){ this.header.remove(item);}} return (A)this;
  }
  public java.util.List<io.fabric8.tekton.pipeline.v1beta1.Param> getHeader() {
    return this.header;
  }
  public io.fabric8.tekton.pipeline.v1beta1.Param getHeader(java.lang.Integer index) {
    return this.header.get(index);
  }
  public io.fabric8.tekton.pipeline.v1beta1.Param getFirstHeader() {
    return this.header.get(0);
  }
  public io.fabric8.tekton.pipeline.v1beta1.Param getLastHeader() {
    return this.header.get(header.size() - 1);
  }
  public io.fabric8.tekton.pipeline.v1beta1.Param getMatchingHeader(java.util.function.Predicate<io.fabric8.tekton.pipeline.v1beta1.Param> predicate) {
    for (io.fabric8.tekton.pipeline.v1beta1.Param item: header) { if(predicate.test(item)){ return item;} } return null;
  }
  public java.lang.Boolean hasMatchingHeader(java.util.function.Predicate<io.fabric8.tekton.pipeline.v1beta1.Param> predicate) {
    for (io.fabric8.tekton.pipeline.v1beta1.Param item: header) { if(predicate.test(item)){ return true;} } return false;
  }
  public A withHeader(java.util.List<io.fabric8.tekton.pipeline.v1beta1.Param> header) {
    if (header != null) {this.header = new java.util.ArrayList(); for (io.fabric8.tekton.pipeline.v1beta1.Param item : header){this.addToHeader(item);}} else { this.header = null;} return (A) this;
  }
  public A withHeader(io.fabric8.tekton.pipeline.v1beta1.Param... header) {
    if (this.header != null) {this.header.clear();}
    if (header != null) {for (io.fabric8.tekton.pipeline.v1beta1.Param item :header){ this.addToHeader(item);}} return (A) this;
  }
  public java.lang.Boolean hasHeader() {
    return header != null && !header.isEmpty();
  }
  
  /**
   * This method has been deprecated, please use method buildObjectRef instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.kubernetes.api.model.ObjectReference getObjectRef() {
    return this.objectRef!=null?this.objectRef.build():null;
  }
  public io.fabric8.kubernetes.api.model.ObjectReference buildObjectRef() {
    return this.objectRef!=null?this.objectRef.build():null;
  }
  public A withObjectRef(io.fabric8.kubernetes.api.model.ObjectReference objectRef) {
    _visitables.get("objectRef").remove(this.objectRef);
    if (objectRef!=null){ this.objectRef= new io.fabric8.kubernetes.api.model.ObjectReferenceBuilder(objectRef); _visitables.get("objectRef").add(this.objectRef);} return (A) this;
  }
  public java.lang.Boolean hasObjectRef() {
    return this.objectRef != null;
  }
  public io.fabric8.tekton.triggers.v1alpha1.WebhookInterceptorFluent.ObjectRefNested<A> withNewObjectRef() {
    return new io.fabric8.tekton.triggers.v1alpha1.WebhookInterceptorFluentImpl.ObjectRefNestedImpl();
  }
  public io.fabric8.tekton.triggers.v1alpha1.WebhookInterceptorFluent.ObjectRefNested<A> withNewObjectRefLike(io.fabric8.kubernetes.api.model.ObjectReference item) {
    return new io.fabric8.tekton.triggers.v1alpha1.WebhookInterceptorFluentImpl.ObjectRefNestedImpl(item);
  }
  public io.fabric8.tekton.triggers.v1alpha1.WebhookInterceptorFluent.ObjectRefNested<A> editObjectRef() {
    return withNewObjectRefLike(getObjectRef());
  }
  public io.fabric8.tekton.triggers.v1alpha1.WebhookInterceptorFluent.ObjectRefNested<A> editOrNewObjectRef() {
    return withNewObjectRefLike(getObjectRef() != null ? getObjectRef(): new io.fabric8.kubernetes.api.model.ObjectReferenceBuilder().build());
  }
  public io.fabric8.tekton.triggers.v1alpha1.WebhookInterceptorFluent.ObjectRefNested<A> editOrNewObjectRefLike(io.fabric8.kubernetes.api.model.ObjectReference item) {
    return withNewObjectRefLike(getObjectRef() != null ? getObjectRef(): item);
  }
  public java.lang.String getUrl() {
    return this.url;
  }
  public A withUrl(java.lang.String url) {
    this.url=url; return (A) this;
  }
  public java.lang.Boolean hasUrl() {
    return this.url != null;
  }
  
  /**
   * Method is deprecated. use withUrl instead.
   */
  @java.lang.Deprecated
  public A withNewUrl(java.lang.String arg0) {
    return (A)withUrl(new String(arg0));
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    WebhookInterceptorFluentImpl that = (WebhookInterceptorFluentImpl) o;
    if (header != null ? !header.equals(that.header) :that.header != null) return false;
    if (objectRef != null ? !objectRef.equals(that.objectRef) :that.objectRef != null) return false;
    if (url != null ? !url.equals(that.url) :that.url != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(header,  objectRef,  url,  super.hashCode());
  }
  public class ObjectRefNestedImpl<N> extends io.fabric8.kubernetes.api.model.ObjectReferenceFluentImpl<io.fabric8.tekton.triggers.v1alpha1.WebhookInterceptorFluent.ObjectRefNested<N>> implements io.fabric8.tekton.triggers.v1alpha1.WebhookInterceptorFluent.ObjectRefNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{
    ObjectRefNestedImpl(io.fabric8.kubernetes.api.model.ObjectReference item) {
      this.builder = new io.fabric8.kubernetes.api.model.ObjectReferenceBuilder(this, item);
    }
    ObjectRefNestedImpl() {
      this.builder = new io.fabric8.kubernetes.api.model.ObjectReferenceBuilder(this);
    }
    io.fabric8.kubernetes.api.model.ObjectReferenceBuilder builder;
    public N and() {
      return (N) WebhookInterceptorFluentImpl.this.withObjectRef(builder.build());
    }
    public N endObjectRef() {
      return and();
    }
    
  }
  
}
